.. _cli:

======================
Command Line Interface
======================

Load config
-----------

::
    
    vcspull up <config>

    vcspull up myproject myproject

    # separate by spaces
    vcspull up vim myproject
